@@ -1,4 +1,4 @@
-from typing import Dict, Any, List
+from typing import Dict, Any, List, Optional
 
 from algora.api.service.project.package.__util import (
     _create_project_package_request_info, _get_project_package_request_info, _get_project_packages_request_info,
@@ -40,18 +40,23 @@ async def async_get_project_packages() -> List[Dict[str, Any]]:
 
 
 @async_data_request(transformer=no_transform)
-async def async_search_project_packages(name: str, version: str) -> Dict[str, Any]:
+async def async_search_project_packages(
+        name: Optional[str] = None,
+        version: Optional[str] = None,
+        tag: Optional[str] = None
+) -> List[Dict[str, Any]]:
     """
-    Asynchronously search for a project package based off of the name and version.
+    Asynchronously get all project packages.
 
     Parameters:
-        name: Project package name
-        version: Project package version
+        name: Optional name parameter to filter the results by
+        version: Optional version parameter to filter the results by
+        tag: Optional tag parameter to filter the results by
 
     Returns:
-        Dict[str, Any]: Project package response
+        List[Dict[str, Any]]: List of project package response
     """
-    request_info = _search_project_packages_request_info(name, version)
+    request_info = _search_project_packages_request_info(name, version, tag)
     return await __async_get_request(**request_info)
 
 
