@@ -2,7 +2,7 @@
 Common types.
 """
 from datetime import date, datetime
-from typing import NewType, Union, List, Dict
+from typing import NewType, Union
 
 from pandas import DataFrame
 
